==> micro_kernel-0.2.tar.gz: micro_kernel-0.2/user/module/i386lib/bus_space.c <==
/*	$NetBSD: bus_space.c,v 1.7 2006/11/16 01:32:39 christos Exp $	*/

/*-
 * Copyright (c) 1996, 1997, 1998 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Charles M. Hannum and by Jason R. Thorpe of the Numerical Aerospace
 * Simulation Facility, NASA Ames Research Center.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the NetBSD
 *	Foundation, Inc. and its contributors.
 * 4. Neither the name of The NetBSD Foundation nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * 2008: modified by minoru murashima.
 */

#include <sys/errno.h>
#include <sys/systm.h>
#include <i386lib/bus.h>

//=====================================  ===================================================

//===================================== Х륤ݡ =======================================

extern int SetUserIomap(const uint , const uint );

//===================================== PRIVATE ====================================================

//===================================== PUBLIC =====================================================

/*
 * return : error number
 */
int x86_memio_map(
	bus_space_tag_t t,
	bus_addr_t bpa,
	bus_size_t size,
	int flags,
	bus_space_handle_t *bshp)
{
	*bshp = bpa;

	/*
	 * Pick the appropriate extent map.
	 */
	if (t == X86_BUS_SPACE_IO) {
		if (flags & BUS_SPACE_MAP_LINEAR) {
			return (EOPNOTSUPP);
		}
	} 
	else if (t == X86_BUS_SPACE_MEM) {
		return setUserIomap(bpa, size);
	}
	else {
		panic("x86_memio_map: bad bus space tag");
	}

	return 0;
}

/*
 *ԸƤեͥء
 */
void x86_memio_unmap(
	bus_space_tag_t t,
	bus_space_handle_t bsh,
	bus_size_t size)
{
	if (t == X86_BUS_SPACE_IO) {
		// ⤷ʤ
	} 
	else if (t == X86_BUS_SPACE_MEM) {
		// ⤷ʤ
	} 
	else {
		panic("x86_memio_unmap: bad bus space tag");
	}
}

==> micro_kernel-0.3.tar.gz: micro_kernel-0.3/user/module/i386lib/bus_space.c <==
/*	$NetBSD: bus_space.c,v 1.7 2006/11/16 01:32:39 christos Exp $	*/

/*-
 * Copyright (c) 1996, 1997, 1998 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Charles M. Hannum and by Jason R. Thorpe of the Numerical Aerospace
 * Simulation Facility, NASA Ames Research Center.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the NetBSD
 *	Foundation, Inc. and its contributors.
 * 4. Neither the name of The NetBSD Foundation nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * 2008: modified by minoru murashima.
 */

#include <sys/errno.h>
#include <sys/systm.h>
#include <i386lib/bus.h>

//=====================================  ===================================================

//===================================== Х륤ݡ =======================================

extern int setUserIoAccess(const uint, const uint);

//===================================== PRIVATE ====================================================

//===================================== PUBLIC =====================================================

/*
 * return : error number
 */
int x86_memio_map(
	bus_space_tag_t t,
	bus_addr_t bpa,
	bus_size_t size,
	int flags,
	bus_space_handle_t *bshp)
{
	*bshp = bpa;

	/*
	 * Pick the appropriate extent map.
	 */
	if (t == X86_BUS_SPACE_IO) {
		if (flags & BUS_SPACE_MAP_LINEAR) {
			return (EOPNOTSUPP);
		}
	} 
	else if (t == X86_BUS_SPACE_MEM) {
		return setUserIoAccess(bpa, size);
	}
	else {
		panic("x86_memio_map: bad bus space tag");
	}

	return 0;
}

/*
 *ԸƤեͥء
 */
void x86_memio_unmap(
	bus_space_tag_t t,
	bus_space_handle_t bsh,
	bus_size_t size)
{
	if (t == X86_BUS_SPACE_IO) {
		// ⤷ʤ
	} 
	else if (t == X86_BUS_SPACE_MEM) {
		// ⤷ʤ
	} 
	else {
		panic("x86_memio_unmap: bad bus space tag");
	}
}

int x86_memio_subregion(
	bus_space_tag_t t, 
	bus_space_handle_t bsh,
    bus_size_t offset, 
    bus_size_t size, 
    bus_space_handle_t *nbshp)
{
	*nbshp = bsh + offset;
	return (0);
}
